function fprod = DiscreteEvidence(tree, allvarnames, evidence, prodvar)
%fprod = DiscreteEvidence(tree, allvarnames, evidence, prodvar)
%
% function for entering discrete nodes evidence to the discrete part of a
% hybrid discrete/continuous Bayesian network.
%
% INPUT : 
%   TREE : the junction tree, an array of ClusterSetTree objects
%   ALLVARNAMES : cell array of names of variables for which evidence has
%       been observed.
%   EVIDENCE : the values of ALLVARNAMES that have been observed
%   PRODVAR : the product variable name, a string representing which node
%       to perform the factor product operation upon.
%
% Copyright Michael McGeachie, 2010.  MIT license. See cgbayesnets_license.txt.


% collect all CPTs from each discrete ClusterSetTree
cpts = repmat(CondProbTable(), size(tree));
cptindex = false(size(tree));
for i = 1:length(tree)
    if (tree(i).discrete)
        cpts(i) = tree(i).cpt;
        cptindex(i) = true;
    end
end


% step 2: reduce all conditional probability tables, to 
% their evidence
freds = factorreduce(cpts(cptindex),allvarnames,evidence);

% step 3: compute a product of these factors on PRODVAR
fprod = factorproduct(freds, prodvar);
    